==> haskell-swagger2-2.2.2-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2.2
id: swagger2-2.2.2-HCOm7yvCvTy3XS2kQVMaHO
key: swagger2-2.2.2-HCOm7yvCvTy3XS2kQVMaHO
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: 0a14576a0b4c742a70fae5ac5895d83f
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/swagger2-2.2.2
hs-libraries: HSswagger2-2.2.2-HCOm7yvCvTy3XS2kQVMaHO
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    template-haskell-2.13.0.0 time-1.8.0.2 transformers-0.5.5.0
    mtl-2.2.2 text-1.2.3.0
    base-compat-batteries-0.10.1-8OmQKIeRUfc9d5uOba9tfI
    aeson-1.3.1.1-7kf596GzYv639jIakibG7C
    generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-GjKsnZDvq3G4xa4qIwljOE
    lens-4.17-LxcltwM7qPcDQIAMOmNPQC
    network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             base-compat-batteries-0.10.1-8OmQKIeRUfc9d5uOba9tfI=12839091e76cdf609072f8ca1e680cd5
             aeson-1.3.1.1-7kf596GzYv639jIakibG7C=783fe341c59350977e3b3224b7e36aa4
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=395f3c6f10a85f11577aaff4e7955339
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             insert-ordered-containers-0.2.1.0-GjKsnZDvq3G4xa4qIwljOE=0e89ab7107161d340dfd238b368db111
             lens-4.17-LxcltwM7qPcDQIAMOmNPQC=99b1443fd2d1e52c81bb44d3da89599c
             network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv=9f4c0094002519cc1dc579d0a3bd3879
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=b4d53b96ebd09e78eeddd19077455aea
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.2.2-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2.2
id: swagger2-2.2.2-EVeQYaNblm3pRgUOxWgPw
key: swagger2-2.2.2-EVeQYaNblm3pRgUOxWgPw
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: ef2f07357d13da0cd17667311f4b3fca
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/swagger2-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/swagger2-2.2.2
hs-libraries: HSswagger2-2.2.2-EVeQYaNblm3pRgUOxWgPw
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    template-haskell-2.13.0.0 time-1.8.0.2 transformers-0.5.5.0
    mtl-2.2.2 text-1.2.3.0
    base-compat-batteries-0.10.1-AUs9ldGqZdKKvtSVvl9E7e
    aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq
    generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-ExBYCWjURDEFGiphfXCS3W
    lens-4.17-Jl3rxJOpxBgAImtpk31J8b
    network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             base-compat-batteries-0.10.1-AUs9ldGqZdKKvtSVvl9E7e=842c864979107fe066d13bf08dc82f4d
             aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq=0bddb8c122a0181e324f08c1b045cf5c
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=395f3c6f10a85f11577aaff4e7955339
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             insert-ordered-containers-0.2.1.0-ExBYCWjURDEFGiphfXCS3W=f8518dbb9a55efaaa249b0162fbb5b5c
             lens-4.17-Jl3rxJOpxBgAImtpk31J8b=ffcabe526701fd7464c499736e21ef25
             network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya=34c8f87548d66d5af3596a33ad5000fc
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo=64a561e4e9a96e6da50de53181f89cb1
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=b4d53b96ebd09e78eeddd19077455aea
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
